import { useEffect } from 'react';
import { Routes, Route, Navigate, useNavigate } from 'react-router-dom'
import { useSelector, useDispatch } from 'react-redux'
import { setUdid, setAccessToken, setUserInfo, setSelectInfo } from "./business/userSlice.js"
import { useCookies } from 'react-cookie';
import LoginPage from './LoginPage';
import MainPage from './MainPage';
import yzs from "./business/request.js";

function App() {
  const dispatch = useDispatch();
  const navigate = useNavigate();
  const [cookies, setCookie, removeCookie] = useCookies(['accessToken']);
  const udid = useSelector(state => state.user.udid)

  const getIp = async () => {
    const response = await fetch("https://ipapi.co/json/")
    const data = await response.json()
    dispatch(setUdid(data.ip));
  }

  // Run `getIP` function above just once when the page is rendered
  useEffect(() => {
    getIp()
  }, [])

  if (cookies.accessToken) {
    dispatch(setAccessToken(cookies.accessToken));
    yzs.get_user_info(udid, cookies.accessToken).then(info => {
      dispatch(setUserInfo(info));
      yzs.user_select(udid, cookies.accessToken).then(info => {
        dispatch(setSelectInfo(info));
      });
    }).catch(error => {
      console.log(error)
      if (error.returnCode === "uc_0106") {
        removeCookie("accessToken");
        navigate("/login");
      }
    });
  }
  return (
    <div className="App">
      <Routes>
        <Route exact path="/" element={cookies.accessToken ? <MainPage /> : <Navigate to="/login" />} />
        <Route exact path="/login" element={<LoginPage />} />
      </Routes>
    </div>
  );
}

export default App;
