import { useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux'
import AppBar from './AppBar';
import RecordList from './RecordList';
import PlayerBar from './PlayerBar';
import styles from './MainPage.module.css';
import yzs from "./business/request.js";
import { setList } from "./business/recorderSlice.js"
import { CssBaseline, Box, Container, Typography } from '@mui/material';
import RecordLyrics from './RecordLyrics';
import { createTheme, ThemeProvider } from '@mui/material/styles';

const theme = createTheme({
    status: {
        danger: '#e53e3e',
    },
    palette: {
        primary: {
            main: '#FF595A',
            darker: '#FF595A',
        },
        neutral: {
            main: '#64748B',
            contrastText: '#fff',
        },
        black: {
            main: "#222222",
        }
    },
});



export default function () {
    const dispatch = useDispatch()
    const accessToken = useSelector(state => state.user.accessToken);
    const passportId = useSelector(state => state.user.passportId);
    const currentTime = useSelector(state => state.recorder.currentTime);
    useEffect(() => {
        yzs.get_record_list(accessToken, passportId).then(list => {
            dispatch(setList(list.result));
        });
    }, [accessToken, passportId]);
    return <div className={styles.mainBody}>
        <ThemeProvider theme={theme}>
            <CssBaseline />
            <AppBar />
            <RecordList />
            <Box
                component="main"
                sx={{
                    width: `calc(100% - 296px)`,
                    ml: `272px`,
                    mr: `24px`,
                }}
            >
                <PlayerBar currentTime={currentTime} />
                <RecordLyrics currentTime={currentTime} />
            </Box>
        </ThemeProvider>
    </div >
}