import { MenuItem, Select, IconButton, Typography, Stack, Container } from "@mui/material"
import styles from './PlayerBar.module.css';
import { useSelector, useDispatch } from 'react-redux'
import { useEffect, useRef, useState, useCallback } from "react";
import { useResizeDetector } from 'react-resize-detector';
import pauseIcon from "./assets/play.png";
import playIcon from "./assets/pause.png";
import downloadIcon from "./assets/download.png";
import { setCurrentTime, togglePauseState } from "./business/recorderSlice.js"
import Waveform from "./components/Waveform";

const durationFormat = (time) => {
    if (isNaN(time)) return "00:00:00";
    time = parseInt(time);
    let second = parseInt(time % 60);
    let minute = parseInt((time / 60) % 60);
    let hour = parseInt(time / 3600);
    return hour.toString().padStart(2, '0') + ":" + minute.toString().padStart(2, '0') + ":" + second.toString().padStart(2, '0');
}

export default function ({ currentTime }) {
    const dispatch = useDispatch();
    const [duration, setDuration] = useState(0);
    const [canvasWidth, setCanvasWidth] = useState(0);
    const currentIndex = useSelector(state => state.recorder.currentIndex);
    const recordList = useSelector(state => state.recorder.list);
    const currentBlob = useSelector(state => state.recorder.currentBlob);
    const pause = useSelector(state => state.recorder.pause);
    const player = useRef(null);
    useEffect(() => {
        player.current.url = currentBlob
        console.log(player.current.url);
    }, [currentBlob]);

    const toggleState = () => {
        if (pause) {
            player.current.play();
        } else {
            player.current.pause();
        }
        dispatch(togglePauseState());
    };

    const onDurationChange = (event) => {
        setDuration(player.current.duration);
    }
    const onTimeUpdate = (event) => {
        dispatch(setCurrentTime(player.current.currentTime));
    }

    const onResize = useCallback((width, height) => {
        setCanvasWidth(width - 90 - 60);
    }, []);

    const { ref: playerBar } = useResizeDetector({
        onResize: onResize
    });

    const seekRecord = (second) => {
        player.current.currentTime = second;
    }

    return <Stack container sx={{
        position: "sticky",
        top: 48,
        backgroundColor: "#FAFAFA",
    }} >
        <Container disableGutters maxWidth={false} sx={{
            height: 60,
            display: "flex",
            alignItems: "center",
        }}>
            <Typography variant="h6" sx={{ flexGrow: 1 }} >{recordList.length > 0 ? recordList.at(currentIndex).editName : ""}</Typography>
            <IconButton onClick={toggleState}>
                <img src={downloadIcon} />
            </IconButton>
        </Container>

        <div className={styles.playerBar} ref={playerBar}>
            <IconButton onClick={toggleState} sx={{ flexGrow: 1, width: 70, height: 70 }}>
                <img src={pause ? pauseIcon : playIcon} />
            </IconButton>

            <audio autoplay ref={player} src={currentBlob} onDurationChange={onDurationChange} onTimeUpdate={onTimeUpdate} />
            <Waveform width={canvasWidth} duration={duration} currentTime={currentTime} playing={!pause} seek={seekRecord} />
            <Select
                defaultValue={1.0}
                sx={{
                    flexGrow: 1,
                    width: 90
                }}
            >
                <MenuItem value={0.5}>0.5X</MenuItem>
                <MenuItem value={1.0}>1.0X</MenuItem>
                <MenuItem value={1.25}>1.25X</MenuItem>
                <MenuItem value={1.5}>1.5X</MenuItem>
                <MenuItem value={2.0}>2.0X</MenuItem>
            </Select>
        </div>

        <Container maxWidth={false} sx={{ backgroundColor: "#F2F4F5" }}>
            <Typography sx={{ color: "#6B7486" }}>  {durationFormat(currentTime)} / {durationFormat(duration)}</Typography>

        </Container>
    </Stack>
}